@@ -74,7 +74,7 @@ public:
 		delete dec;
 	}
 
-	void reset()
+	void reset() override
 	{
 		delete dec;
 		dec = 0;
@@ -112,7 +112,7 @@ public:
 		return last;
 	}
 
-	QChar next()
+	QChar next() override
 	{
 		if(paused)
 			return EndOfData;
@@ -371,18 +371,18 @@ namespace XMPP
 			}
 		}
 
-		bool startDocument()
+		bool startDocument() override
 		{
 			depth = 0;
 			return true;
 		}
 
-		bool endDocument()
+		bool endDocument() override
 		{
 			return true;
 		}
 
-		bool startPrefixMapping(const QString &prefix, const QString &uri)
+		bool startPrefixMapping(const QString &prefix, const QString &uri) override
 		{
 			if(depth == 0) {
 				nsnames += prefix;
@@ -391,7 +391,7 @@ namespace XMPP
 			return true;
 		}
 
-		bool startElement(const QString &namespaceURI, const QString &localName, const QString &qName, const QXmlAttributes &atts)
+		bool startElement(const QString &namespaceURI, const QString &localName, const QString &qName, const QXmlAttributes &atts) override
 		{
 			if(depth == 0) {
 				Parser::Event *e = new Parser::Event;
@@ -441,7 +441,7 @@ namespace XMPP
 			return true;
 		}
 
-		bool endElement(const QString &namespaceURI, const QString &localName, const QString &qName)
+		bool endElement(const QString &namespaceURI, const QString &localName, const QString &qName) override
 		{
 			--depth;
 			if(depth == 0) {
@@ -475,7 +475,7 @@ namespace XMPP
 			return true;
 		}
 
-		bool characters(const QString &str)
+		bool characters(const QString &str) override
 		{
 			if(depth >= 1) {
 				QString content = str;
@@ -610,7 +610,7 @@ QString Parser::Event::nsprefix(const QString &s) const
 			return (*it2);
 		++it2;
 	}
-	return QString::null;
+	return QString();
 }
 
 QString Parser::Event::namespaceURI() const
